@@ -17,8 +17,8 @@ package Dist::Zilla::Plugin::PodLoom;
 # ABSTRACT: Process module documentation through Pod::Loom
 #---------------------------------------------------------------------
 
-our $VERSION = '5.00';
-# This file is part of Dist-Zilla-Plugin-PodLoom 5.00 (November 13, 2013)
+our $VERSION = '5.001';
+# This file is part of Dist-Zilla-Plugin-PodLoom 5.001 (July 18, 2015)
 
 
 use Moose 0.65; # attr fulfills requires
@@ -106,13 +106,19 @@ sub munge_file
   my $abstract = Dist::Zilla::Util->abstract_from_file($file);
   my $repo     = $self->zilla->distmeta->{resources}{repository};
 
+  my $module = $info->name;
+  if (!$module or $module eq 'main') {
+    $module = $file->name;
+    $module =~ s!^.*/!!s;       # Strip directory names
+  }
+
   my $dataHash = Hash::Merge::Simple::merge(
     {
       ($abstract ? (abstract => $abstract) : ()),
       authors        => $self->zilla->authors,
       dist           => $self->zilla->name,
       license_notice => $self->zilla->license->notice,
-      ($info->name ? (module => $info->name) : ()),
+      module         => $module,
       bugtracker     => $self->zilla->distmeta->{resources}{bugtracker},
       repository     => $repo->{web} || $repo->{url},
       # Have to stringify version object:
@@ -153,9 +159,9 @@ Dist::Zilla::Plugin::PodLoom - Process module documentation through Pod::Loom
 
 =head1 VERSION
 
-This document describes version 5.00 of
-Dist::Zilla::Plugin::PodLoom, released November 13, 2013
-as part of Dist-Zilla-Plugin-PodLoom version 5.00.
+This document describes version 5.001 of
+Dist::Zilla::Plugin::PodLoom, released July 18, 2015
+as part of Dist-Zilla-Plugin-PodLoom version 5.001.
 
 =head1 SYNOPSIS
 
@@ -203,8 +209,10 @@ C<< $zilla->license->notice >>
 
 =item module
 
-The primary package of the file being processed
-(if Module::Build::ModuleInfo could determine it)
+The primary package of the file being processed.  If Module::Metadata
+could not determine the package, or if it is explicitly C<main>, this
+is the filename (without directories), because that's the equivalent
+of a package name for scripts.
 
 =item repository
 
@@ -214,7 +222,7 @@ C<< $zilla->distmeta->{resources}{repository}{web} >>
 =item version
 
 The version number of the file being processed
-(if Module::Build::ModuleInfo could determine it)
+(if Module::Metadata could determine it)
 
 =item zilla
 
@@ -260,7 +268,7 @@ L<< https://github.com/madsen/dist-zilla-plugin-podloom >>.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Christopher J. Madsen.
+This software is copyright (c) 2015 by Christopher J. Madsen.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
